#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Copyright (c) 2022 mundialis GmbH & Co. KG

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

Response models
"""

__license__ = "GPLv3"
__author__ = "Anika Weinmann"
__copyright__ = "Copyright 2022 mundialis GmbH & Co. KG"
__maintainer__ = "mundialis GmbH % Co. KG"


from flask_restful_swagger_2 import Schema


class MergeShortDescResponseModel(Schema):
    """Response schema for short description of merge processes."""
    type = "object"
    properties = {
        "categories": {
            "type": "array",
            "items": {"type": "string"},
            "description": "Categories of the process."
        },
        "description": {
            "type": "string",
            "description": "Description of the process."
        },
        "id": {
            "type": "string",
            "description": "ID of the process."
        }
    }
    required = ["categories", "id", "description"]
    example = {
        "merge_processes": [
            {
                "categories": ["Tiling"],
                "description": "Merge raster, vector and STRDS data from "
                "different mapsets defined in a 'mapsetlist' by patching them "
                "in the new/target mapset.",
                "id": "patch"
            }
        ]
    }


class MergeListResponseModel(Schema):
    """Merge process list reponse schema."""
    type = "object"
    properties = {
        "merge_processes": {
            "type": "array",
            "items": {"type": MergeShortDescResponseModel},
            "description": "The list of all available merge processes."
        }
    }
    required = ["merge_processes"]
    example = [
        {
            "merge_processes": [
                {
                    "categories": ["Merge"],
                    "description": "Merge raster, vector and STRDS data from "
                    "different mapsets defined in a 'mapsetlist' by patching "
                    "them in the new/target mapset.",
                    "id": "patch"
                }
            ]
        },
        200
    ]
